@@ -1,6 +1,7 @@
 from manimlib import *
 from .tools import calc_number_step
 
+
 def m_line(x,
            y,
            z=None,
@@ -10,43 +11,13 @@ def m_line(x,
            optacity=None,
            background=None):
     """point data to line"""
-    L = len(x)
     x, y = np.array(x), np.array(y)
-    if z is None:
-        z = np.zeros(x.shape)
-    if axes is None:
-        # last_little_line = Line([x[L - 1], y[L - 1], z[0]], [x[0], y[0], z[0]])
-        line = VGroup(*[
-            Line([x[i], y[i], 0], [x[i + 1], y[i + 1]]).set_stroke(
-                color=color,
-                width=width,
-                opacity=optacity,
-                background=background) for i in range(len(x) - 1)
-        ])
-    elif type(axes) is Axes:
-        # last_little_line = Line(axes.c2p(x[L - 1], y[L - 1]),
-        #                         axes.c2p(x[0], y[0]))
-        line = VGroup(*[
-            Line(axes.c2p(x[i], y[i]), axes.c2p(x[i + 1], y[
-                i + 1])).set_stroke(color=color,
-                                    width=width,
-                                    opacity=optacity,
-                                    background=background)
-            for i in range(len(x) - 1)
-        ])
-    else:  # ThreeDAxes
-        # last_little_line = Line(axes.c2p(x[L - 1], y[L - 1], z[0]),
-        #                         axes.c2p(x[0], y[0], z[0])).set_stroke(
-        #     color=color, width=width, opacity=optacity, background=background)
-
-        line = VGroup(*[
-            Line(axes.c2p(x[i], y[i], z[i]), axes.c2p(x[i + 1], y[
-                i + 1], z[i])).set_stroke(color=color,
-                                          width=width,
-                                          opacity=optacity,
-                                          background=background)
-            for i in range(len(x) - 1)
-        ])
+    line = PlotObj(x, y, z, axes).set_stroke(
+        color=color,
+        width=width,
+        opacity=optacity,
+        background=background
+    )
     return line
 
 
@@ -85,31 +56,24 @@ class Plot:
         self._axes_height = 6.2
         self._axes_ratio = 0.62
         self._scale_ratio = None
-        self._num_decimal_places = (1, 1)
+        self._num_decimal_places = None
         self._show_axes = True
         self._include_tip = True
         self._x_label = 'x'
         self._y_label = 'y'
 
     def create_axes(self, x_label_min, x_label_max, y_label_min, y_label_max):
+
         x_length = x_label_max - x_label_min
         y_length = y_label_max - y_label_min
-        dx = x_length / 20
-        dy = y_length / 15
 
-        xmin, xmax = x_label_min - EPSILON, x_label_max + dx
-        ymin, ymax = y_label_min - EPSILON, y_label_max + dy
-
-        if self._scale_ratio is not None:
-            tick_ratio = self._scale_ratio * y_length/ x_length
-        else:
-            tick_ratio = self._axes_ratio
-
-        self._axes_height = self._axes_width * tick_ratio
-
-        if self._axes_height > 7:
-            self._axes_height = 7
-            self._axes_width = self._axes_height / tick_ratio
+        """
+         * 确定x, y轴比例
+         * 当前轴在屏幕中的长度是多少: L
+         * 这个长度适合显示多少个刻度标签: N
+         * 如何分配这N个标签, 即N个具体数值
+         * 每个数值应显示的有效位数 可通过小数点末位的零来判断 
+        """
 
         # n_x = 10
         # n_y = n_x * tick_ratio
@@ -118,8 +82,45 @@ class Plot:
         n_step_x, x_step = calc_number_step(x_length)
         n_step_y, y_step = calc_number_step(y_length)
 
+        def adjust_axes_ratio(x_length, y_length):
+            if self._scale_ratio is not None:
+                tick_ratio = self._scale_ratio * y_length / x_length
+            else:
+                tick_ratio = self._axes_ratio
+
+            self._axes_height = self._axes_width * tick_ratio
+
+            if self._axes_height > 7:
+                self._axes_height = 7
+                self._axes_width = self._axes_height / tick_ratio
+            return tick_ratio
+
+        tick_ratio = adjust_axes_ratio(x_length, y_length)
+        # FIXME: stupid here
         if n_step_y / n_step_x > tick_ratio + 0.3:
-            y_step *= 2
+            y_step *= 5
+        xmin, xmax = x_label_min - EPSILON, x_label_max + x_step / 2
+        ymin, ymax = y_label_min - EPSILON, y_label_max + y_step / 2
+        adjust_axes_ratio(xmax - xmin, ymax - ymin)
+
+        def get_exponent_num(number):
+            def get_error_remain(num, n):
+                approx_num = round(num, n)
+                return abs(approx_num - num)
+
+            if get_error_remain(number, 0) < 1e-2:
+                return 0
+            if get_error_remain(number, 1) < 1e-2:
+                return 1
+            else:
+                return 2
+
+        if self._num_decimal_places is not None:
+            x_num_decimal_place = self._num_decimal_places[0]
+            y_num_decimal_place = self._num_decimal_places[1]
+        else:
+            x_num_decimal_place = min(max(get_exponent_num(x_label_min), get_exponent_num(x_step)), 2)
+            y_num_decimal_place = min(max(get_exponent_num(y_label_min), get_exponent_num(y_step)), 2)
 
         axes = Axes(
             x_range=(xmin, xmax, x_step),
@@ -139,14 +140,14 @@ class Plot:
             x_axis_config={
                 "tip_config": {"width": 0.1, "length": 0.25},
                 "decimal_number_config": {
-                    "num_decimal_places": self._num_decimal_places[0],
+                    "num_decimal_places": x_num_decimal_place,
                     "font_size": 15,
                 },
             },
             y_axis_config={
                 "tip_config": {"width": 0.15, "length": 0.3},
                 "decimal_number_config": {
-                    "num_decimal_places": self._num_decimal_places[1],
+                    "num_decimal_places": y_num_decimal_place,
                     "font_size": 15,
                 },
             },
@@ -197,21 +198,20 @@ class Plot:
             self._axes_line_list.append(line)
 
             line.shift(-self._unit_x * self._xmin * RIGHT)
-            # self._axes_line_list.append(line)
 
     def plot(
-        self,
-        x,
-        y,
-        color=None,
-        width=None,
-        axes_ratio=0.618,
-        scale_ratio=None,
-        show_axes=True,
-        include_tip=True,
-        num_decimal_places=(1, 1),
-        x_label='x',
-        y_label='y',
+            self,
+            x,
+            y,
+            color=None,
+            width=None,
+            axes_ratio=0.618,
+            scale_ratio=None,
+            show_axes=True,
+            include_tip=True,
+            num_decimal_places=None,
+            x_label='x',
+            y_label='y',
     ):
         self.num += 1
         self._show_axes = show_axes
@@ -234,3 +234,50 @@ class Plot:
         self._include_tip = include_tip
         self._x_label = x_label
         self._y_label = y_label
+
+
+class PlotObj(VMobject):
+    InstantCount = 0
+    CONFIG = {
+        "epsilon": 1e-8,
+        "discontinuities": [],
+        "use_smoothing": True,
+    }
+
+    def __init__(self, x, y, z=None, axes=None, **kwargs):
+        PlotObj.InstantCount += 1
+        digest_config(self, kwargs)
+        self.points = xyz_to_points(x, y, z, axes)
+        VMobject.__init__(self, **kwargs)
+
+    def init_points(self):
+        x = self.points[:, 0]
+        t_min, t_max = x.min(), x.max()
+
+        jumps = np.array(self.discontinuities)
+        jumps = jumps[(jumps > t_min) & (jumps < t_max)]
+        boundary_times = [t_min, t_max, *(jumps - self.epsilon), *(jumps + self.epsilon)]
+        boundary_times.sort()
+        for t1, t2 in zip(boundary_times[0::2], boundary_times[1::2]):
+            points = self.points
+            self.start_new_path(points[0])
+            self.add_points_as_corners(points[1:])
+        if self.use_smoothing:
+            self.make_approximately_smooth()
+        return self
+
+
+def xyz_to_points(x, y, z=None, axes=None):
+    assert len(x) == len(y)
+    if z is None:
+        z = np.zeros(len(x))
+    if axes is not None:
+        if type(axes) is Axes:
+            # axes: Axes
+            points = np.array([axes.c2p(i, j) for i, j in zip(x, y)])
+        else:
+            axes: ThreeDAxes
+            points = np.array([axes.c2p(i, j, k) for i, j, k in zip(x, y, z)])
+    else:
+        points = np.stack([x, y, z], 1)
+    return points
